==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/ImageStreamTagBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ImageStreamTagBuilder extends io.fabric8.openshift.api.model.ImageStreamTagFluentImpl<io.fabric8.openshift.api.model.ImageStreamTagBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ImageStreamTag,io.fabric8.openshift.api.model.ImageStreamTagBuilder>{
  public ImageStreamTagBuilder() {
    this(false);
  }
  public ImageStreamTagBuilder(java.lang.Boolean validationEnabled) {
    this(new ImageStreamTag(), validationEnabled);
  }
  public ImageStreamTagBuilder(io.fabric8.openshift.api.model.ImageStreamTagFluent<?> fluent) {
    this(fluent, false);
  }
  public ImageStreamTagBuilder(io.fabric8.openshift.api.model.ImageStreamTagFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ImageStreamTag(), validationEnabled);
  }
  public ImageStreamTagBuilder(io.fabric8.openshift.api.model.ImageStreamTagFluent<?> fluent,io.fabric8.openshift.api.model.ImageStreamTag instance) {
    this(fluent, instance, false);
  }
  public ImageStreamTagBuilder(io.fabric8.openshift.api.model.ImageStreamTagFluent<?> fluent,io.fabric8.openshift.api.model.ImageStreamTag instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withConditions(instance.getConditions()); 
    fluent.withGeneration(instance.getGeneration()); 
    fluent.withImage(instance.getImage()); 
    fluent.withKind(instance.getKind()); 
    fluent.withLookupPolicy(instance.getLookupPolicy()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withTag(instance.getTag()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ImageStreamTagBuilder(io.fabric8.openshift.api.model.ImageStreamTag instance) {
    this(instance,false);
  }
  public ImageStreamTagBuilder(io.fabric8.openshift.api.model.ImageStreamTag instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withConditions(instance.getConditions()); 
    this.withGeneration(instance.getGeneration()); 
    this.withImage(instance.getImage()); 
    this.withKind(instance.getKind()); 
    this.withLookupPolicy(instance.getLookupPolicy()); 
    this.withMetadata(instance.getMetadata()); 
    this.withTag(instance.getTag()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ImageStreamTagFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ImageStreamTag build() {
    ImageStreamTag buildable = new ImageStreamTag(fluent.getApiVersion(),fluent.getConditions(),fluent.getGeneration(),fluent.getImage(),fluent.getKind(),fluent.getLookupPolicy(),fluent.getMetadata(),fluent.getTag());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageStreamTagBuilder that = (ImageStreamTagBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-6.3.1-sources.jar: io/fabric8/openshift/api/model/ImageStreamTagBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ImageStreamTagBuilder extends ImageStreamTagFluentImpl<ImageStreamTagBuilder> implements VisitableBuilder<ImageStreamTag,ImageStreamTagBuilder>{
  public ImageStreamTagBuilder() {
    this(false);
  }
  public ImageStreamTagBuilder(Boolean validationEnabled) {
    this(new ImageStreamTag(), validationEnabled);
  }
  public ImageStreamTagBuilder(ImageStreamTagFluent<?> fluent) {
    this(fluent, false);
  }
  public ImageStreamTagBuilder(ImageStreamTagFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ImageStreamTag(), validationEnabled);
  }
  public ImageStreamTagBuilder(ImageStreamTagFluent<?> fluent,ImageStreamTag instance) {
    this(fluent, instance, false);
  }
  public ImageStreamTagBuilder(ImageStreamTagFluent<?> fluent,ImageStreamTag instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withConditions(instance.getConditions()); 
    fluent.withGeneration(instance.getGeneration()); 
    fluent.withImage(instance.getImage()); 
    fluent.withKind(instance.getKind()); 
    fluent.withLookupPolicy(instance.getLookupPolicy()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withTag(instance.getTag()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ImageStreamTagBuilder(ImageStreamTag instance) {
    this(instance,false);
  }
  public ImageStreamTagBuilder(ImageStreamTag instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withConditions(instance.getConditions()); 
    this.withGeneration(instance.getGeneration()); 
    this.withImage(instance.getImage()); 
    this.withKind(instance.getKind()); 
    this.withLookupPolicy(instance.getLookupPolicy()); 
    this.withMetadata(instance.getMetadata()); 
    this.withTag(instance.getTag()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ImageStreamTagFluent<?> fluent;
  Boolean validationEnabled;
  public ImageStreamTag build() {
    ImageStreamTag buildable = new ImageStreamTag(fluent.getApiVersion(),fluent.getConditions(),fluent.getGeneration(),fluent.getImage(),fluent.getKind(),fluent.getLookupPolicy(),fluent.getMetadata(),fluent.getTag());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
